@@ -32,7 +32,7 @@
 #pragma warning( disable : 4786 )
 #endif /* TAU_WINDOWS */
 
-#ifdef __cplusplus 
+#if (defined (__cplusplus ) && !defined (TAU_USE_C_API))
 
 #include <Profile/ProfileGroups.h>
 
@@ -63,7 +63,7 @@
 #include <Profile/RtsLayer.h>
 
 #include <Profile/FunctionInfo.h>
-			  
+
 #include <Profile/UserEvent.h>
 
 #include <Profile/PclLayer.h>
@@ -141,6 +141,13 @@ public:
 				      int tid = RtsLayer::myThread(), 
 				      char *prefix = "dump");
 
+	static void getUserEventList(const char ***inPtr, int *numUserEvents);
+
+	static void getUserEventValues(const char **inUserEvents, int numUserEvents,
+				       int **numEvents, double **max, double **min,
+				       double **mean, double **sumSqr, 
+				       int tid = RtsLayer::myThread());
+
 #if ( defined(PROFILE_CALLS) || defined(PROFILE_STATS) || defined(PROFILE_CALLSTACK) ) 
 	int ExcludeTimeThisCall(double t);
 	double ExclTimeThisCall; // for this invocation of the function
@@ -191,13 +198,13 @@ private:
 #endif /* PROFILING_ON || TRACING_ON */
 #include <Profile/TauMapping.h>
 // included after class Profiler is defined.
-#else /* __cplusplus */
+#else /* __cplusplus && ! TAU_USE_C_API */
 #include <Profile/TauCAPI.h> /* For C program */
-#endif /* __cplusplus */
+#endif /* __cplusplus && ! TAU_USE_C_API */
 
 #endif /* PROFILER_H */
 /***************************************************************************
  * $RCSfile: Profiler.h,v $   $Author: sameer $
- * $Revision: 1.50 $   $Date: 2004/02/26 22:28:35 $
- * POOMA_VERSION_ID: $Id: Profiler.h,v 1.50 2004/02/26 22:28:35 sameer Exp $ 
+ * $Revision: 1.52 $   $Date: 2004/10/30 00:34:08 $
+ * POOMA_VERSION_ID: $Id: Profiler.h,v 1.52 2004/10/30 00:34:08 sameer Exp $ 
  ***************************************************************************/
