@@ -60,6 +60,8 @@ class RtsLayer
   
 	static int& TheContext(void);
 
+	static long GenerateUniqueId(void);
+
  	static ProfileMap_t& TheProfileMap(void);
 
  	static TauGroup_t  getProfileGroup(char *  ProfileGroup) ;
@@ -116,6 +118,9 @@ class RtsLayer
 	// For tracing 
 	static int 	DumpEDF(int tid); 
 
+	// For tracing
+	static int      MergeAndConvertTracesIfNecessary();
+
   	// Return the number of the 'current' node.
 	static int myNode(void);
 
@@ -139,6 +144,6 @@ class RtsLayer
 #endif /* _RTSLAYER_H_  */
 /***************************************************************************
  * $RCSfile: RtsLayer.h,v $   $Author: sameer $
- * $Revision: 1.18 $   $Date: 2003/12/11 21:59:02 $
- * POOMA_VERSION_ID: $Id: RtsLayer.h,v 1.18 2003/12/11 21:59:02 sameer Exp $ 
+ * $Revision: 1.20 $   $Date: 2004/08/21 21:58:16 $
+ * POOMA_VERSION_ID: $Id: RtsLayer.h,v 1.20 2004/08/21 21:58:16 sameer Exp $ 
  ***************************************************************************/
