@@ -105,7 +105,13 @@ extern "C" void Tau_stop_top_level_timer_if_necessary(void);
 #define TAU_DUMP_FUNC_VALS_INCR(v1,v2) \
                                Profiler::dumpFunctionValues(v1,v2,true);
 
+
 // UserEvents
+
+#define TAU_GET_EVENT_NAMES(eventList, num) Profiler::getUserEventList(&eventList, &num);
+#define TAU_GET_EVENT_VALS(v1,v2,v3,v4,v5,v6,v7) \
+                               Profiler::getUserEventValues(v1,v2,&v3,&v4,&v5,&v6,&v7);
+
 #define TAU_REGISTER_EVENT(event, name)  	TauUserEvent event(name);
 #define TAU_EVENT(event, data) 		 	(event).TriggerEvent(data);
 #define TAU_EVENT_SET_NAME(event, name) 	(event).SetEventName(name);
@@ -199,6 +205,7 @@ extern "C" void Tau_stop_top_level_timer_if_necessary(void);
 #define TAU_ENABLE_TRACKING_MEMORY()
 #define TAU_DISABLE_TRACKING_MEMORY()
 #define TAU_TRACK_MEMORY()
+#define TAU_TRACK_MEMORY_HERE()
 #define TAU_ENABLE_TRACKING_MUSE_EVENTS()	
 #define TAU_DISABLE_TRACKING_MUSE_EVENTS()
 #define TAU_TRACK_MUSE_EVENTS()		
@@ -228,7 +235,7 @@ extern "C" void Tau_stop_top_level_timer_if_necessary(void);
 
 #endif /* _TAU_API_H_ */
 /***************************************************************************
- * $RCSfile: TauAPI.h,v $   $Author: sameer $
- * $Revision: 1.32 $   $Date: 2004/06/10 18:08:30 $
- * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.32 2004/06/10 18:08:30 sameer Exp $ 
+ * $RCSfile: TauAPI.h,v $   $Author: amorris $
+ * $Revision: 1.34 $   $Date: 2004/10/04 23:32:14 $
+ * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.34 2004/10/04 23:32:14 amorris Exp $ 
  ***************************************************************************/
