@@ -30,7 +30,10 @@
 #ifndef _TAU_CAPI_H_
 #define _TAU_CAPI_H_
 
-#ifndef __cplusplus
+#if ((! defined( __cplusplus)) || defined (TAU_USE_C_API))
+#ifdef TAU_USE_C_API
+extern "C" {
+#endif /* TAU_USE_C_API */
 /* For C */
 #include <stdio.h>
 #include <Profile/ProfileGroups.h>
@@ -74,6 +77,10 @@
 #define TAU_DUMP_FUNC_VALS(functionList, num)   Tau_dump_function_values(functionList, num);
 #define TAU_DUMP_FUNC_VALS_incr(functionList, num)  Tau_dump_function_values_incr(functionList, num);
 
+
+#define TAU_GET_EVENT_NAMES(eventList, num)     Tau_get_event_names(&eventList, &num);
+#define TAU_GET_EVENT_VALS(v1,v2,v3,v4,v5,v6)   Tau_get_event_vals(v1,v2,&v3,&v4,&v5,&v6);
+
 /*
 #define TAU_REGISTER_EVENT(event, name)	static int tauuser##event = 1;\
 				        static void *event; \ 
@@ -251,6 +258,7 @@ extern void Tau_set_interrupt_interval(int value);
 #define TAU_ENABLE_TRACKING_MEMORY()
 #define TAU_DISABLE_TRACKING_MEMORY()
 #define TAU_TRACK_MEMORY()
+#define TAU_TRACK_MEMORY_HERE()
 #define TAU_ENABLE_TRACKING_MUSE_EVENTS()	
 #define TAU_DISABLE_TRACKING_MUSE_EVENTS()
 #define TAU_TRACK_MUSE_EVENTS()		
@@ -273,13 +281,16 @@ extern void Tau_set_interrupt_interval(int value);
         Tau_trace_recvmsg(type, source, length);
 #endif /* TRACING_ON */
 
+#ifdef TAU_USE_C_API
+}
+#endif /* TAU_USE_C_API */
 
-#endif /* __cplusplus */
+#endif /* ! __cplusplus || TAU_C_API */
 #endif /* _TAU_CAPI_H_ */
 
 /***************************************************************************
  * $RCSfile: TauCAPI.h,v $   $Author: sameer $
- * $Revision: 1.30 $   $Date: 2004/06/10 18:08:29 $
- * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.30 2004/06/10 18:08:29 sameer Exp $
+ * $Revision: 1.33 $   $Date: 2004/10/30 00:34:08 $
+ * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.33 2004/10/30 00:34:08 sameer Exp $
  ***************************************************************************/
 
