@@ -58,6 +58,16 @@
 #define TAU_DISABLE_GROUP_NAME(group)
 #define TAU_ENABLE_ALL_GROUPS()			
 #define TAU_DISABLE_ALL_GROUPS()	
+#define TAU_TRACK_MEMORY()
+#define TAU_TRACK_MEMORY_HERE()
+#define TAU_ENABLE_TRACKING_MEMORY()
+#define TAU_DISABLE_TRACKING_MEMORY()
+#define TAU_TRACK_MEMORY()
+#define TAU_TRACK_MEMORY_HERE()
+#define TAU_ENABLE_TRACKING_MUSE_EVENTS()	
+#define TAU_DISABLE_TRACKING_MUSE_EVENTS()
+#define TAU_TRACK_MUSE_EVENTS()		
+#define TAU_SET_INTERRUPT_INTERVAL(value)
 
 #define CT(obj)
 
