@@ -46,15 +46,17 @@ using namespace std;
 #include <stdlib.h>
 
 #if (!defined(TAU_WINDOWS))
-#include <unistd.h>
-#if (defined(POOMA_TFLOP) || !defined(TULIP_TIMERS))
-#include <sys/time.h>
-#else
-#ifdef TULIP_TIMERS 
-#include "Profile/TulipTimers.h"
-#endif //TULIP_TIMERS 
-#endif //POOMA_TFLOP
+ #include <unistd.h>
+ #if (defined(POOMA_TFLOP) || !defined(TULIP_TIMERS))
+  #include <sys/time.h>
+ #else
+  #ifdef TULIP_TIMERS 
+   #include "Profile/TulipTimers.h"
+  #endif //TULIP_TIMERS 
+ #endif //POOMA_TFLOP
 
+#else
+  #include <vector>
 #endif //TAU_WINDOWS
 
 #ifdef TRACING_ON
@@ -181,7 +183,10 @@ void FunctionInfo::FunctionInfoInit(TauGroup_t ProfileGroup,
 	// a lock in RtsLayer that can be locked while the push_back
 	// and size operations are done (this should be atomic). 
 	// Function Id is the index into the DB vector
-	FunctionId = TheFunctionDB().size();
+	/* OLD:
+	 * FunctionId = TheFunctionDB().size();
+	 */
+	FunctionId = RtsLayer::GenerateUniqueId();
 	SetFlushEvents(tid);
 #endif /* TAU_EPILOG */
 #endif //TRACING_ON
@@ -193,6 +198,9 @@ void FunctionInfo::FunctionInfoInit(TauGroup_t ProfileGroup,
 	  << " Group :  " << MyProfileGroup_ 
 	  << " Type : " << GetType() << endl;);
 
+#ifdef TAU_PROFILEMEMORY
+	MemoryEvent = new TauUserEvent(string(Name+" "+Type+" - Heap Memory (KB)").c_str());
+#endif /* TAU_PROFILEMEMORY */
 	return;
 }
 //////////////////////////////////////////////////////////////////////
@@ -307,7 +315,7 @@ long FunctionInfo::GetFunctionId(void)
 //////////////////////////////////////////////////////////////////////
 
 /***************************************************************************
- * $RCSfile: FunctionInfo.cpp,v $   $Author: sameer $
- * $Revision: 1.32 $   $Date: 2003/05/20 18:44:28 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.cpp,v 1.32 2003/05/20 18:44:28 sameer Exp $ 
+ * $RCSfile: FunctionInfo.cpp,v $   $Author: amorris $
+ * $Revision: 1.35 $   $Date: 2004/09/01 18:52:35 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.cpp,v 1.35 2004/09/01 18:52:35 amorris Exp $ 
  ***************************************************************************/
