@@ -28,10 +28,20 @@ using namespace std;
 #include <sys/param.h>
 #endif // CRAY_TIMERS
 
+#ifdef TRACING_ON
+#ifdef TAU_EPILOG
+#include "elg_trc.h"
+#else /* TAU_EPILOG */
+#define PCXX_EVENT_SRC
+#include "Profile/pcxx_events.h"
+#endif /* TAU_EPILOG */
+#endif // TRACING_ON
+
 #ifdef TAU_MPI
-extern "C" TauUserEvent sendevent;
+extern TauUserEvent& TheSendEvent(void);
 #endif /* TAU_MPI */
 
+
 //Initialize static members.
 char MultipleCounterLayer::environment[25][10] = {
   {"COUNTER1"},{"COUNTER2"},{"COUNTER3"},{"COUNTER4"},{"COUNTER5"},
@@ -96,6 +106,10 @@ PCL_CNT_TYPE MultipleCounterLayer::CounterList[MAX_TAU_COUNTERS];
 PCL_FP_CNT_TYPE MultipleCounterLayer::FpCounterList[MAX_TAU_COUNTERS];
 #endif//TAU_PCL
 
+#ifdef TRACING_ON
+TauUserEvent **MultipleCounterLayer::counterEvents; 
+#endif /* TRACING_ON */
+
 firstListType MultipleCounterLayer::initArray[] = {gettimeofdayMCLInit,
 						   linuxTimerMCLInit,
 						   sgiTimersMCLInit,
@@ -207,9 +221,10 @@ bool MultipleCounterLayer::initializeMultiCounterLayer(void)
 	  functionPosition++;
 	  //Update the number of active functions.
 	  numberOfActiveFunctions++;
+	  //cout <<"numberOfActiveFunctions = "<<numberOfActiveFunctions<<endl;
 
-	  //cout << "Adding function to position: " 
-	  //     << e << " of the init array." << endl;
+	  // cout << "Adding function to position: " 
+	  //      << e << " of the init array." << endl;
       }
       else{
 	//cout << "Not function to position: " 
@@ -222,6 +237,19 @@ bool MultipleCounterLayer::initializeMultiCounterLayer(void)
     //but it is nice to give a warning.
     if(numberOfActiveFunctions == 0)
       cout << "Warning: No multi counter fncts active ... are the env variables COUNTER<1-N> set?" << endl;
+#ifdef TRACING_ON
+   int countersUsed = getNumberOfCountersUsed();
+   counterEvents = new TauUserEvent * [countersUsed] ; 
+   /* We obtain the timestamp from COUNTER1, so we only need to trigger 
+      COUNTER2-N or i=1 through no. of active functions not through 0 */
+   RtsLayer::UnLockDB(); // mutual exclusion primitive AddEventToDB locks it
+   for (int i = 1; i < countersUsed; i++)
+   {
+     counterEvents[i] = new TauUserEvent(names[i], true);
+     /* the second arg is MonotonicallyIncreasing which is true (HW counters)*/ 
+   }
+   RtsLayer::LockDB(); // We do this to prevent a deadlock. Lock it again!
+#endif /* TRACING_ON */
   }
   RtsLayer::UnLockDB(); // mutual exclusion primitive
    
@@ -479,7 +507,9 @@ bool MultipleCounterLayer::papiMCLInit(int functionPosition){
 	      counter++;
 	    }
 	    MultipleCounterLayer::names[i][counter]='\0';
+#ifdef DEBUG_PROF
 	    cout << "Adjusted counter name is: " << names[i] << endl;
+#endif /* DEBUG_PROF */
 	  }
 	  PapiLayer::multiCounterPapiInit();
 	  int tmpCode = PapiLayer::map_eventnames(MultipleCounterLayer::names[i]);
@@ -647,7 +677,7 @@ void MultipleCounterLayer::tauMUSEMCL(int tid, double values[]){
 
 void MultipleCounterLayer::tauMPIMessageSizeMCL(int tid, double values[]){
 #ifdef TAU_MPI
-  values[tauMPIMessageSizeMCL_CP[0]] = sendevent.GetSumValue(tid); //Currently TAU_EVENT_DATATYPE is a double.
+  values[tauMPIMessageSizeMCL_CP[0]] = TheSendEvent().GetSumValue(tid); //Currently TAU_EVENT_DATATYPE is a double.
 #endif//TAU_MPI
 }
 
@@ -864,6 +894,39 @@ void MultipleCounterLayer::linuxTimerMCL(int tid, double values[]){
 #endif //TAU_LINUX_TIMERS
 }
 
+/////////////////////////////////////////////////
+// Get number of counters
+/////////////////////////////////////////////////
+int MultipleCounterLayer::getNumberOfCountersUsed(void)
+{
+  int i, numberOfCounters=0;
+  for(i=0;i<MAX_TAU_COUNTERS;i++){
+    char *tmpChar = getCounterNameAt(i);
+    if((tmpChar != NULL) && (MultipleCounterLayer::getCounterUsed(i))){
+      numberOfCounters++;
+    }
+  }
+  return numberOfCounters; 
+}
+
+#if ( defined(TAU_MULTIPLE_COUNTERS) && defined(TRACING_ON))
+
+/////////////////////////////////////////////////
+// Trigger user defined events associated with each counter 
+/////////////////////////////////////////////////
+void MultipleCounterLayer::triggerCounterEvents(unsigned long long timestamp, double *values, int tid)
+{
+  int i;
+  static int countersUsed = MultipleCounterLayer::getNumberOfCountersUsed();
+  for (i = 1; i < countersUsed; i++)
+  { /* for each event */
+    TraceEvent(counterEvents[i]->GetEventId(), (long long) values[i], tid, timestamp, 1);
+    // 1 in the last parameter is for use timestamp 
+  }
+
+}
+#endif /* TAU_MULTIPLE_COUNTERS && TRACING_ON */
+
 /////////////////////////////////////////////////
 //
 //End - Definintions for MultipleCounters.
