@@ -33,9 +33,17 @@
 //#define DEBUG_PROF // For Debugging Messages from Profiler.cpp
 #include "Profile/Profiler.h"
 
-#ifndef TAU_WINDOWS
+#ifdef TAU_WINDOWS
+  typedef __int64 x_int64;
+  typedef unsigned __int64 x_uint64;
+#else
+  typedef long long x_int64;
+  typedef unsigned long long x_uint64;
+#endif
+
+//#ifndef TAU_WINDOWS
 extern "C" void Tau_shutdown(void);
-#endif //TAU_WINDOWS
+//#endif //TAU_WINDOWS
 
 #ifdef TAU_DOT_H_LESS_HEADERS
 #include <iostream>
@@ -161,7 +169,7 @@ char * TauGetCounterString(void)
 
 void Profiler::Start(int tid)
 { 
-      unsigned long long TimeStamp = 0L;
+      x_uint64 TimeStamp = 0L;
       DEBUGPROFMSG("Profiler::Start: MyProfileGroup_ = " << MyProfileGroup_ 
         << " Mask = " << RtsLayer::TheProfileMask() <<endl;);
       if ((MyProfileGroup_ & RtsLayer::TheProfileMask()) 
@@ -169,13 +177,16 @@ void Profiler::Start(int tid)
 	if (ThisFunction == (FunctionInfo *) NULL) return; // Mapping
       DEBUGPROFMSG("Profiler::Start Entering " << ThisFunction->GetName()<<endl;);
 	
+#ifdef TAU_PROFILEMEMORY
+      ThisFunction->GetMemoryEvent()->TriggerEvent(TauGetMaxRSS());
+#endif /* TAU_PROFILEMEMORY */
 #ifdef TAU_COMPENSATE
 	SetNumChildren(0); /* for instrumentation perturbation compensation */
 #endif /* TAU_COMPENSATE */
 	// Initialization is over, now record the time it started
 #ifndef TAU_MULTIPLE_COUNTERS 
 	StartTime =  RtsLayer::getUSecD(tid) ;
-	TimeStamp += (unsigned long long) StartTime;
+	TimeStamp += (x_uint64) StartTime;
 #else //TAU_MULTIPLE_COUNTERS
 	//Initialize the array to zero, as some of the elements will
 	//not be set by counting functions.
@@ -200,6 +211,9 @@ void Profiler::Start(int tid)
 	TraceEvent(ThisFunction->GetFunctionId(), 1, tid, TimeStamp, 1); 
 	// 1 is for entry in second parameter and for use TimeStamp in last
 	DEBUGPROFMSG("Start TimeStamp for Tracing = "<<TimeStamp<<endl;);
+#ifdef TAU_MULTIPLE_COUNTERS 
+	MultipleCounterLayer::triggerCounterEvents(TimeStamp, StartTime, tid);
+#endif /* TAU_MULTIPLE_COUNTERS */
 #endif /* TAU_EPILOG */
 #endif /* TRACING_ON */
 
@@ -335,7 +349,7 @@ Profiler& Profiler::operator= (const Profiler& X)
 
 void Profiler::Stop(int tid)
 {
-      unsigned long long TimeStamp = 0L; 
+      x_uint64 TimeStamp = 0L; 
       if (CurrentProfiler[tid] == NULL) return;
       DEBUGPROFMSG("Profiler::Stop: MyProfileGroup_ = " << MyProfileGroup_ 
         << " Mask = " << RtsLayer::TheProfileMask() <<endl;);
@@ -359,7 +373,7 @@ void Profiler::Stop(int tid)
 #ifndef TAU_MULTIPLE_COUNTERS
 	double CurrentTime = RtsLayer::getUSecD(tid);
 	double TotalTime = CurrentTime - StartTime;
-	TimeStamp += (unsigned long long) CurrentTime; 
+	TimeStamp += (x_uint64) CurrentTime; 
 
 
 #if (defined(TAU_COMPENSATE ) && defined(PROFILING_ON))
@@ -410,6 +424,9 @@ void Profiler::Stop(int tid)
 	// -1 is for exit, 1 is for use TimeStamp in the last argument
 	DEBUGPROFMSG("Stop TimeStamp for Tracing = "<<TimeStamp<<endl;);
 #endif /* TAU_EPILOG */
+#ifdef TAU_MULTIPLE_COUNTERS 
+	MultipleCounterLayer::triggerCounterEvents(TimeStamp, CurrentTime, tid);
+#endif /* TAU_MULTIPLE_COUNTERS */
 #endif //TRACING_ON
 
 #ifdef PROFILING_ON  // Calculations relevent to profiling only 
@@ -678,8 +695,8 @@ void Profiler::dumpFunctionNames()
 
   //Create temp write to file.
   filename = new char[1024];
-  sprintf(filename,"%s/temp.%d.%d",dirname, RtsLayer::myNode(),
-	  RtsLayer::myContext());
+  sprintf(filename,"%s/temp.%d.%d.%d",dirname, RtsLayer::myNode(),
+	  RtsLayer::myContext(), RtsLayer::myThread());
   if ((fp = fopen (filename, "w+")) == NULL) {
     errormsg = new char[1024];
     sprintf(errormsg,"Error: Could not create %s",filename);
@@ -696,11 +713,68 @@ void Profiler::dumpFunctionNames()
   
   //Rename from the temp filename.
   dumpfile = new char[1024];
-  sprintf(dumpfile,"%s/dump_functionnames_n,c.%d.%d",dirname, RtsLayer::myNode(),
-                RtsLayer::myContext());
+  sprintf(dumpfile,"%s/dump_functionnames_n,c,t.%d.%d.%d",dirname, RtsLayer::myNode(),
+	  RtsLayer::myContext(), RtsLayer::myThread());
   rename(filename, dumpfile);
 }
 
+void Profiler::getUserEventList(const char ***inPtr, int *numUserEvents) {
+
+  *numUserEvents = 0;
+
+  vector<TauUserEvent*>::iterator eit;
+  
+  for (eit = TheEventDB().begin(); eit != TheEventDB().end(); eit++) {
+    (*numUserEvents)++;
+  }
+  
+  *inPtr = (char const **) malloc(sizeof(char*) * *numUserEvents);
+
+  for(int i=0;i<*numUserEvents;i++) {
+    (*inPtr)[i] = TheEventDB()[i]->GetEventName();
+  }
+}
+
+
+void Profiler::getUserEventValues(const char **inUserEvents, int numUserEvents,
+				  int **numEvents, double **max, double **min,
+				  double **mean, double **sumSqr, int tid) {
+
+  TAU_PROFILE("TAU_GET_EVENT_VALUES()", " ", TAU_IO);
+
+#ifdef PROFILING_ON
+
+  *numEvents = (int*) malloc (sizeof(int) * numUserEvents);
+  *max = (double *) malloc (sizeof(double) * numUserEvents);
+  *min = (double *) malloc (sizeof(double) * numUserEvents);
+  *mean = (double *) malloc (sizeof(double) * numUserEvents);
+  *sumSqr = (double *) malloc (sizeof(double) * numUserEvents);
+
+  RtsLayer::LockDB();
+
+  int idx = 0;
+  vector<TauUserEvent*>::iterator eit;
+
+  for (eit = TheEventDB().begin(); eit != TheEventDB().end(); eit++) {
+    for (int i=0;i<numUserEvents;i++) {
+      if ((inUserEvents != 0) && (strcmp(inUserEvents[i], (*eit)->GetEventName()) == 0)){
+	(*numEvents)[idx] = (*eit)->GetNumEvents(tid);
+	(*max)[idx] = (*eit)->GetMax(tid);
+	(*min)[idx] = (*eit)->GetMin(tid);
+	(*mean)[idx] = (*eit)->GetMean(tid);
+	(*sumSqr)[idx] = (*eit)->GetSumSqr(tid);
+	idx++;
+	break;
+      }
+    }
+  }
+
+  RtsLayer::UnLockDB();
+#endif //PROFILING_ON
+  
+}
+
+
 #ifndef TAU_MULTIPLE_COUNTERS
 void Profiler::theCounterList(const char ***inPtr, int *numOfCounters)
 {
@@ -1101,6 +1175,7 @@ int Profiler::StoreData(int tid)
 #else /* TAU_EPILOG */
 	TraceEvClose(tid);
 	RtsLayer::DumpEDF(tid);
+	RtsLayer::MergeAndConvertTracesIfNecessary();
 #endif /* TAU_EPILOG */
 #endif // TRACING_ON 
 
@@ -2014,6 +2089,9 @@ int Profiler::dumpFunctionValues(const char **inFuncs,
   return 1;
 }
 
+
+
+
 int Profiler::StoreData(int tid){
 #ifdef PROFILING_ON
   vector<FunctionInfo*>::iterator it;
@@ -2037,6 +2115,7 @@ int Profiler::StoreData(int tid){
 #else /* TAU_EPILOG */
 	TraceEvClose(tid);
 	RtsLayer::DumpEDF(tid);
+	RtsLayer::MergeAndConvertTracesIfNecessary();
 #endif /* TAU_EPILOG */
 #endif // TRACING_ON
 
@@ -2419,7 +2498,7 @@ int Profiler::DumpData(bool increment, int tid, char *prefix){
     }
   }
 #elif TRACING_ON
-  TraceEvFlush();
+  TraceEvFlush(tid);
 #endif //PROFILING_ON
   return 1;
 }
@@ -2634,9 +2713,9 @@ void Profiler::AddNumChildren(long value)
 
 
 /***************************************************************************
- * $RCSfile: Profiler.cpp,v $   $Author: sameer $
- * $Revision: 1.97 $   $Date: 2004/06/16 00:26:55 $
- * POOMA_VERSION_ID: $Id: Profiler.cpp,v 1.97 2004/06/16 00:26:55 sameer Exp $ 
+ * $RCSfile: Profiler.cpp,v $   $Author: amorris $
+ * $Revision: 1.104 $   $Date: 2004/10/04 23:32:15 $
+ * POOMA_VERSION_ID: $Id: Profiler.cpp,v 1.104 2004/10/04 23:32:15 amorris Exp $ 
  ***************************************************************************/
 
 	
