@@ -42,6 +42,13 @@
 #include "Profile/hitachi.h"
 #endif /* HITACHI */
 #include "Profile/Profiler.h"
+#ifdef TAU_WINDOWS
+ #define TAUROOT "root"
+ #define TAU_ARCH "win32"
+#else
+ #include "tauroot.h"
+ #include "tauarch.h"
+#endif
 
 #ifdef CRAY_TIMERS
 #include <intrinsics.h>
@@ -123,6 +130,13 @@ bool& RtsLayer::TheEnableInstrumentation(void)
   return EnableInstrumentation;
 }
 
+/////////////////////////////////////////////////////////////////////////
+long RtsLayer::GenerateUniqueId(void)
+{ /* This routine is called in a locked region (RtsLayer::LockDB/UnLockDB)*/
+  static long UniqueId = 0;
+  return ++UniqueId;
+}
+
 /////////////////////////////////////////////////////////////////////////
 int& RtsLayer::TheNode(void)
 {
@@ -1030,6 +1044,7 @@ int RtsLayer::DumpEDF(int tid)
 {
 #ifdef TRACING_ON 
   	vector<FunctionInfo*>::iterator it;
+  	vector<TauUserEvent*>::iterator uit;
 	char filename[1024], errormsg[1024];
 	char *dirname;
 	FILE* fp;
@@ -1037,7 +1052,14 @@ int RtsLayer::DumpEDF(int tid)
 
 
 	if (tid != 0) 
-	  return 1; 
+	{ 
+#ifdef DEBUG_PROF
+	  printf("DumpEDF: FlushEvents = %d\n",GetFlushEvents(tid));
+#endif /* DEBUG_PROF */
+	  if (GetFlushEvents(tid) == 0)
+	    return 1; 
+	}
+	RtsLayer::LockDB();
 	// Only thread 0 on a node should write the edf files.
 	if ((dirname = getenv("TRACEDIR")) == NULL) {
 	// Use default directory name .
@@ -1060,7 +1082,10 @@ int RtsLayer::DumpEDF(int tid)
 	// id group tag "name type" parameters
 
 	numExtra = 9; // Number of extra events
+	/* OLD
 	numEvents = TheFunctionDB().size();
+	*/
+	numEvents = TheFunctionDB().size() + TheEventDB().size();
 
 	numEvents += numExtra;
 
@@ -1079,6 +1104,23 @@ int RtsLayer::DumpEDF(int tid)
 	  fprintf(fp, "%ld %s 0 \"%s %s\" EntryExit\n", (*it)->GetFunctionId(),
 	    (*it)->GetPrimaryGroup(), (*it)->GetName(), (*it)->GetType() );
 	}
+
+	/* Now write the user defined event */
+ 	for (uit = TheEventDB().begin(); 
+	  uit != TheEventDB().end(); uit++)
+	{
+	  int monoinc = 0; 
+	  if ((*uit)->GetMonotonicallyIncreasing())
+	  { /* if it is true */
+	    monoinc = 1;
+	  }
+  	  DEBUGPROFMSG("Node: "<< RtsLayer::myNode() <<  " Dumping EDF Id : " 
+	    << (*uit)->GetEventId() << " " 
+	    << monoinc<<" " << (*uit)->GetEventName() << " " 
+	    << " TriggerValue" << endl;); 
+	
+	  fprintf(fp, "%ld TAUEVENT %d \"%s\" TriggerValue\n", (*uit)->GetEventId(), monoinc, (*uit)->GetEventName());
+	}
 	// Now add the nine extra events 
 	fprintf(fp,"%ld TRACER 0 \"EV_INIT\" none\n", (long) PCXX_EV_INIT); 
 	fprintf(fp,"%ld TRACER 0 \"FLUSH_ENTER\" none\n", (long) PCXX_EV_FLUSH_ENTER); 
@@ -1092,10 +1134,88 @@ int RtsLayer::DumpEDF(int tid)
 
   
 	fclose(fp);
+	RtsLayer::UnLockDB();
 #endif //TRACING_ON
 	return 1;
 }
 
+//////////////////////////////////////////////////////////////////////
+// MergeAndConvertTracesIfNecessary does just that!
+//////////////////////////////////////////////////////////////////////
+
+int RtsLayer::MergeAndConvertTracesIfNecessary(void)
+{ 
+  char *outfile;
+  /* Get environment variables */
+  if ((outfile = getenv("TAU_TRACEFILE")) != NULL)
+  { /* output file is defined. We need to merge the traces */
+    /* Now, who does the merge and conversion? */
+    if ((myNode() == 0) && (myThread() == 0))
+    {
+      char *outdir;
+      char *keepfiles;
+      char cmd[1024];
+      char rmcmd[256]; 
+      char cdcmd[1024];
+      char *tauroot=TAUROOT;
+      char *tauarch=TAU_ARCH;
+      char *conv="tau2vtf";
+      char converter[1024] = {0}; 
+      FILE *in;
+  
+      /* If we can't find tau2vtf, use tau_convert! */
+      sprintf(converter, "%s/%s/bin/%s",tauroot, tauarch, conv);
+      if ((in = fopen(converter, "r")) == NULL)
+      {
+#ifdef DEBUG_PROF
+        printf("Couldn't open %s\n", converter);
+#endif /* DEBUG_PROF */
+        sprintf(converter, "%s/%s/bin/tau_convert", tauroot, tauarch);
+      }
+      else
+      { /* close it */
+        fclose(in);
+      }
+
+      /* Should we get rid of intermediate trace files? */
+      if((keepfiles = getenv("TAU_KEEP_TRACEFILES")) == NULL)
+      {
+	strcpy(rmcmd, "/bin/rm -f app12345678.trc tautrace.*.trc tau.edf events.*.edf");
+      }
+      else
+      { 
+	strcpy(rmcmd," "); /* NOOP */
+      }
+
+      /* Next, look for trace directory */
+      if ((outdir = getenv("TRACEDIR")) != NULL)
+      { /* change directory to outdir */
+        sprintf(cdcmd, "cd %s;", outdir);
+      }
+      else
+      {
+	strcpy(cdcmd, " ");
+      }
+
+      /* create the command */
+      sprintf(cmd, "%s /bin/rm -f app12345678.trc; %s/%s/bin/tau_merge tautrace.*.trc app12345678.trc; %s app12345678.trc tau.edf %s; %s", cdcmd,tauroot, tauarch, converter, outfile, rmcmd);
+#ifdef DEBUG_PROF
+      printf("The merge/convert cmd is: %s\n", cmd);
+#endif /* DEBUG_PROF */
+
+      /* and execute it */
+#ifndef TAU_CATAMOUNT
+      system(cmd);
+#endif /* TAU_CATAMOUNT */
+    } /* on node 0, thread 0 */
+  } /* if output file is defined */
+  else 
+  { /* output file not defined, just exit normally */
+    return 0;
+  }
+  return 1;
+}
+
 #ifdef __GNUC__
 #ifndef NO_RTTI
 #include <cxxabi.h>
@@ -1122,6 +1242,6 @@ std::string RtsLayer::GetRTTI(const char *name)
 
 /***************************************************************************
  * $RCSfile: RtsLayer.cpp,v $   $Author: sameer $
- * $Revision: 1.56 $   $Date: 2004/03/03 01:07:49 $
- * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.56 2004/03/03 01:07:49 sameer Exp $ 
+ * $Revision: 1.63 $   $Date: 2004/11/07 00:25:04 $
+ * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.63 2004/11/07 00:25:04 sameer Exp $ 
  ***************************************************************************/
