@@ -68,6 +68,36 @@ void tau_profile_set_context_(int *context)
 void tau_register_thread_(void)
 {
 }
+/* For IBM compiler */
+
+void tau_profile_timer(void **ptr, char *fname, int *flen, char *type, int *tlen, unsigned int *group)
+{
+}
+
+
+void tau_profile_start(void **profiler)
+{ 
+}
+
+void tau_profile_stop(void **profiler)
+{
+}
+
+void tau_profile_exit(char *msg)
+{
+}
+
+void tau_profile_init(int *argc, char **argv)
+{
+}
+
+void tau_profile_set_node(int *node)
+{
+} 
+
+void tau_profile_set_context(int *context)
+{
+}
 
 /* Cray F90 specific extensions */
 #ifdef CRAYKAI
@@ -261,11 +291,183 @@ void tau_event_disable_stddev(void *ue)
 } 
 ///////////////////////////////////////////////////////////////////////////
 
+void tau_profile_timer__(void **ptr, char *fname, int *flen, char *type, int *tlen, unsigned int *group)
+{
+}
 
+
+void tau_profile_start__(void **profiler)
+{ 
+}
+
+void tau_profile_stop__(void **profiler)
+{
+}
+
+void tau_profile_exit__(char *msg)
+{
+}
+
+void tau_profile_init__(int *argc, char **argv)
+{
+}
+
+void tau_profile_set_node__(int *node)
+{
+} 
+
+void tau_profile_set_context__(int *context)
+{
+}
+
+void tau_register_thread__(void)
+{
+}
+
+///////////////////////////////////////////////////////////////////////////
+// Memory, MAGNET/MUSE event stubs
+///////////////////////////////////////////////////////////////////////////
+
+//////////////////////////////////////////////////////
+void tau_track_memory(void)
+{
+} 
+
+void tau_track_memory_here(void)
+{
+} 
+
+void tau_track_muse_events(void)
+{
+} 
+
+void tau_enable_tracking_memory(void)
+{
+} 
+
+void tau_disable_tracking_memory(void)
+{
+} 
+
+void tau_enable_tracking_muse_events(void)
+{
+} 
+
+void tau_disable_tracking_muse_events(void)
+{
+} 
+
+void tau_set_interrupt_interval(int value)
+{
+} 
+
+
+//////////////////////////////////////////////////////
+void tau_track_memory_(void)
+{
+} 
+
+void tau_track_memory_here_(void)
+{
+} 
+
+void tau_track_muse_events_(void)
+{
+} 
+
+void tau_enable_tracking_memory_(void)
+{
+} 
+
+void tau_disable_tracking_memory_(void)
+{
+} 
+
+void tau_enable_tracking_muse_events_(void)
+{
+} 
+
+void tau_disable_tracking_muse_events_(void)
+{
+} 
+
+void tau_set_interrupt_interval_(int value)
+{
+} 
+
+////////////////////////////////////////////////////////////////////////
+void tau_track_memory__(void)
+{
+} 
+
+void tau_track_memory_here__(void)
+{
+} 
+
+void tau_track_muse_events__(void)
+{
+} 
+
+void tau_enable_tracking_memory__(void)
+{
+} 
+
+void tau_disable_tracking_memory__(void)
+{
+} 
+
+void tau_enable_tracking_muse_events__(void)
+{
+} 
+
+void tau_disable_tracking_muse_events__(void)
+{
+} 
+
+void tau_set_interrupt_interval__(int value)
+{
+}
+
+//////////////////////////////////////////////////////
+// MEMORY, MUSE events API
+//////////////////////////////////////////////////////
+void TAU_TRACK_MEMORY(void)
+{
+} 
+
+void TAU_TRACK_MEMORY_HERE(void)
+{
+} 
+
+void TAU_TRACK_MUSE_EVENTS(void)
+{
+} 
+
+void TAU_ENABLE_TRACKING_MEMORY(void)
+{
+} 
+
+void TAU_DISABLE_TRACKING_MEMORY(void)
+{
+} 
+
+void TAU_ENABLE_TRACKING_MUSE_EVENTS(void)
+{
+} 
+
+void TAU_DISABLE_TRACKING_MUSE_EVENTS(void)
+{
+} 
+
+void TAU_SET_INTERRUPT_INTERVAL(int value)
+{
+} 
+
+////////////////////////////////////////////////////////////////////////////
 } /* extern "C" */
 
 /***************************************************************************
  * $RCSfile: TauDisable.cpp,v $   $Author: sameer $
- * $Revision: 1.2 $   $Date: 1999/06/20 17:34:40 $
- * POOMA_VERSION_ID: $Id: TauDisable.cpp,v 1.2 1999/06/20 17:34:40 sameer Exp $ 
+ * $Revision: 1.4 $   $Date: 2004/06/11 21:46:32 $
+ * POOMA_VERSION_ID: $Id: TauDisable.cpp,v 1.4 2004/06/11 21:46:32 sameer Exp $ 
  ***************************************************************************/
