@@ -99,7 +99,7 @@ void tau_profile_timer_group_(void **ptr, char *infname, int *group, int slen)
   }
 
 #ifdef DEBUG_PROF 
-  printf("get_profiler returns %x\n", *ptr);
+  printf("get_profiler returns %lx\n", *ptr);
 #endif /* DEBUG_PROF */
 
   return;
@@ -155,22 +155,23 @@ void tau_extract_groupinfo(char *& fname, TauGroup_t & gr, char *& gr_name)
 void tau_profile_timer_(void **ptr, char *infname, int slen)
 {
   
-  char * fname = (char *) malloc((size_t)slen+1);
-  strncpy(fname, infname, slen);
-  fname[slen] = '\0';
 
 #ifdef DEBUG_PROF
-  printf("Inside tau_profile_timer_ fname=%s\n", fname);
+  printf("Inside tau_profile_timer_ fname=%s\n", infname);
 #endif /* DEBUG_PROF */
   if (*ptr == 0) 
   {  // remove garbage characters from the end of name
+    char * fname = (char *) malloc((size_t)slen+1);
+    strncpy(fname, infname, slen);
+    fname[slen] = '\0';
     
     EXTRACT_GROUP(fname, slen, gr, gr_name)
     *ptr = Tau_get_profiler(fname, (char *)" ", gr, gr_name);
+    free(fname); 
   }
 
 #ifdef DEBUG_PROF 
-  printf("get_profiler returns %x\n", *ptr);
+  printf("get_profiler returns %lx\n", *ptr);
 #endif /* DEBUG_PROF */
 
   return;
@@ -180,7 +181,7 @@ void tau_profile_timer_(void **ptr, char *infname, int slen)
 void tau_profile_start_(void **profiler)
 { 
 #ifdef DEBUG_PROF
-  printf("start_timer gets %x\n", *profiler);
+  printf("start_timer gets %lx\n", *profiler);
 #endif /* DEBUG_PROF */
 
   Tau_start_timer(*profiler);
@@ -299,9 +300,9 @@ void tau_disable_tracking_muse_events(void)
   Tau_disable_tracking_muse_events();
 } 
 
-void tau_set_interrupt_interval(int value)
+void tau_set_interrupt_interval(int* value)
 {
-  Tau_set_interrupt_interval(value);
+  Tau_set_interrupt_interval(*value);
 } 
 
 ////////////////////////////////////////////////////
@@ -470,9 +471,9 @@ void tau_disable_tracking_muse_events_(void)
   Tau_disable_tracking_muse_events();
 } 
 
-void tau_set_interrupt_interval_(int value)
+void tau_set_interrupt_interval_(int* value)
 {
-  Tau_set_interrupt_interval(value);
+  Tau_set_interrupt_interval(*value);
 } 
 
 /* Cray F90 specific extensions */
@@ -510,7 +511,7 @@ void TAU_PROFILE_TIMER(void **ptr, char *fname, int flen)
   }
 
 #ifdef DEBUG_PROF 
-  printf("get_profiler returns %x\n", *ptr);
+  printf("get_profiler returns %lx\n", *ptr);
 #endif /* DEBUG_PROF */
 
   return;
@@ -729,9 +730,9 @@ void TAU_DISABLE_TRACKING_MUSE_EVENTS(void)
   Tau_disable_tracking_muse_events();
 } 
 
-void TAU_SET_INTERRUPT_INTERVAL(int value)
+void TAU_SET_INTERRUPT_INTERVAL(int* value)
 {
-  Tau_set_interrupt_interval(value);
+  Tau_set_interrupt_interval(*value);
 } 
 
 void tau_profile_start(int **profiler)
@@ -830,11 +831,18 @@ void tau_profile_timer__(void **ptr, char *fname, int flen)
 {
   if (*ptr == 0) 
   {  // remove garbage characters from the end of name
-    for(int i=0; i<strlen(fname); i++)
+    char * newname=new char[flen+1] ;
+    for (int j =0; j < flen; j++)
+      newname[j] = fname[j];
+
+    newname[flen] = '\0';
+
+
+    for(int i=0; i<strlen(newname); i++)
     {
-      if (!VALID_NAME_CHAR(fname[i]))
+      if (!VALID_NAME_CHAR(newname[i]))
       { 
-        fname[i] = '\0';
+        newname[i] = '\0';
         break;
       }
     }
@@ -842,8 +850,8 @@ void tau_profile_timer__(void **ptr, char *fname, int flen)
 #ifdef DEBUG_PROF
     printf("Tau_get_profiler() \n");
 #endif /* DEBUG_PROF */
-    EXTRACT_GROUP(fname, flen, gr, gr_name)
-    *ptr = Tau_get_profiler(fname, " ", gr, gr_name);
+    EXTRACT_GROUP(newname, flen, gr, gr_name)
+    *ptr = Tau_get_profiler(newname, " ", gr, gr_name);
   }
 
 #ifdef DEBUG_PROF 
@@ -909,23 +917,28 @@ void tau_trace_recvmsg__(int *type, int *source, int *length)
   Tau_trace_recvmsg(*type, *source, *length);
 }
 
-void tau_register_event__(void **ptr, char *event_name, int *flen)
+void tau_register_event__(void **ptr, char *event_name, int flen)
 {
 
   if (*ptr == 0) 
   {  // remove garbage characters from the end of name
-    for(int i=0; i<1024; i++)
+    char * newname=new char[flen+1] ;
+    for (int j =0; j < flen; j++)
+      newname[j] = event_name[j];
+
+    newname[flen] = '\0';
+    for(int i=0; i<strlen(newname); i++)
     {
-      if (!VALID_NAME_CHAR(event_name[i]))
+      if (!VALID_NAME_CHAR(newname[i]))
       { 
-        event_name[i] = '\0';
+        newname[i] = '\0';
         break;
       }
     }
 #ifdef DEBUG_PROF
     printf("tau_get_userevent() \n");
 #endif /* DEBUG_PROF */
-    *ptr = Tau_get_userevent(event_name);
+    *ptr = Tau_get_userevent(newname);
   }
   return;
 
@@ -1026,9 +1039,9 @@ void tau_disable_tracking_muse_events__(void)
   Tau_disable_tracking_muse_events();
 } 
 
-void tau_set_interrupt_interval__(int value)
+void tau_set_interrupt_interval__(int* value)
 {
-  Tau_set_interrupt_interval(value);
+  Tau_set_interrupt_interval(*value);
 } 
 
 
@@ -1037,6 +1050,6 @@ void tau_set_interrupt_interval__(int value)
 
 /***************************************************************************
  * $RCSfile: TauFAPI.cpp,v $   $Author: sameer $
- * $Revision: 1.30 $   $Date: 2004/06/10 18:07:27 $
- * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.30 2004/06/10 18:07:27 sameer Exp $ 
+ * $Revision: 1.34 $   $Date: 2004/10/20 17:31:39 $
+ * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.34 2004/10/20 17:31:39 sameer Exp $ 
  ***************************************************************************/
