@@ -28,7 +28,7 @@ public class DynaprofOutputSession extends ParaProfDataSession{
 	this.setMetrics(new Vector());
     }
     
-    public void run(){
+    public void initialize(Object initializeObject){
 	try{
 	    //######
 	    //Frequently used items.
@@ -170,7 +170,8 @@ public class DynaprofOutputSession extends ParaProfDataSession{
 			if(totalLine){
 			    if(metric >= 0){
 				//Compute derived data for this metric.
-				thread.setThreadData(metric);
+				//Remove after testing is complete ... check to see if this if/else structure is needed at all after the removal.
+				//thread.setThreadData(metric);
 				metric++;
 			    }
 			    else
@@ -342,11 +343,14 @@ public class DynaprofOutputSession extends ParaProfDataSession{
 			    }
 			}
 		    }
-		    thread.setThreadData(metric);
+		    //Remove after testing is complete.
+		    //thread.setThreadData(metric);
 		}
 
-		//Generate mean data for this trial.
-		this.setMeanDataAllMetrics(0,this.getNumberOfMetrics());
+		//Generate derived data.
+		this.generateDerivedData(0);
+		//Remove after testing is complete.
+		//this.setMeanDataAllMetrics(0);
 
 		System.out.println("Processing callpath data ...");
 		if(CallPathUtilFuncs.isAvailable(getGlobalMapping().getMappingIterator(0))){
@@ -362,16 +366,6 @@ public class DynaprofOutputSession extends ParaProfDataSession{
 		System.out.println("Done processing data!");
 		System.out.println("Time to process (in milliseconds): " + time);
 
-		//Need to notify observers that we are done.  Be careful here.
-	    //It is likely that they will modify swing elements.  Make sure
-	    //to dump request onto the event dispatch thread to ensure
-	    //safe update of said swing elements.  Remember, swing is not thread
-	    //safe for the most part.
-	    EventQueue.invokeLater(new Runnable(){
-		    public void run(){
-			DynaprofOutputSession.this.notifyObservers();
-		    }
-		});
 	    }
 	}
         catch(Exception e){
@@ -443,7 +437,7 @@ public class DynaprofOutputSession extends ParaProfDataSession{
 	    functionChildDataLine.d5 = Double.parseDouble(st.nextToken()); //incl.max
 	}
 	catch(Exception e){
-	    System.out.println("An error occured!");
+	    System.out.println("An error occurred!");
 	    e.printStackTrace();
 	}
     }
