@@ -39,9 +39,13 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
     //######
     //Storage control.
     //######
+    public int getStorageSize() {
+	return doubleList.length / 15;
+    }
+    
     public void incrementStorage(){
 	int currentLength = doubleList.length;
-	double[] newArray = new double[currentLength+14];
+	double[] newArray = new double[currentLength+15];
 	for(int i=0;i<currentLength;i++){
 	    newArray[i] = doubleList[i];
 	}
@@ -50,7 +54,7 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
 
     public void incrementStorage(int increase){
 	int currentLength = doubleList.length;
-	double[] newArray = new double[currentLength+(increase*14)];
+	double[] newArray = new double[currentLength+(increase*15)];
 	for(int i=0;i<currentLength;i++){
 	    newArray[i] = doubleList[i];
 	}
@@ -91,7 +95,7 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
 	return false;
     }
 
-	public int getNumberOfGroups() { return numberOfGroups; }
+    public int getNumberOfGroups() { return numberOfGroups; }
 
     public int[] getGroups(){
 	int[] groups = new int[numberOfGroups];
@@ -316,6 +320,14 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
     public double getMaxUserEventMeanValue(){
 	return maxUserEventMeanValue;
     }
+
+    public void setMaxUserEventSumSquared(double maxUserEventSumSquaredValue){
+	this.maxUserEventSumSquared = maxUserEventSumSquared;}
+  
+    public double getMaxUserEventSumSquared(){
+	return maxUserEventSumSquared;
+    }
+
     //######
     //End - Userevent max section.
     //######
@@ -365,79 +377,27 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
     public double getMeanUserSecPerCall(int location){
   	return this.getDouble(location,9);}
 
-    public String getMeanTotalStatString(int type, int location, int precision){
+    public String getMeanTotalStatString(int type, int metric){
   	try{
-	    int initialBufferLength = 99;
-	    int position = 0;
-	    char [] statStringArray = new char[initialBufferLength];
-	    char [] tmpArray;
+	    
 	    String tmpString;
+	    
+	    DecimalFormat dF = new DecimalFormat("##0.0");
+	    tmpString = UtilFncs.lpad(dF.format(this.getMeanInclusivePercentValue(metric)),7);
       
-	    this.insertSpaces(statStringArray , 0, 99);
-      
-	    DecimalFormat dF = new DecimalFormat();
-	    dF.applyPattern("##0.0");
-	    tmpArray = (dF.format(this.getMeanInclusivePercentValue(location))).toCharArray();
-      
-	    for(int i=0;i<tmpArray.length;i++){
-		statStringArray[position] = tmpArray[i];
-		position++;
-	    }
-      
-	    position = 9;
-	    tmpString = UtilFncs.getOutputString(type,this.getMeanExclusiveValue(location),precision);
+	    tmpString = tmpString + "  " + UtilFncs.getOutputString(type,this.getMeanExclusiveValue(metric),14);
+	    tmpString = tmpString + "  " + UtilFncs.getOutputString(type,this.getMeanInclusiveValue(metric),16);
+	    tmpString = tmpString + "  " + UtilFncs.formatDouble(this.getMeanNumberOfCalls(),12);
+	    tmpString = tmpString + "  " + UtilFncs.formatDouble(this.getMeanNumberOfSubRoutines(),12);
+	    tmpString = tmpString + "  " + UtilFncs.getOutputString(type,this.getMeanUserSecPerCall(metric),19);
 
-	    tmpArray = tmpString.toCharArray();
-	    for(int i=0;i<tmpArray.length;i++){
-		statStringArray[position] = tmpArray[i];
-		position++;
-	    }
-      
-	    position = 27;
-	    tmpString = UtilFncs.getOutputString(type,this.getMeanInclusiveValue(location),precision);
-
-	    tmpArray = tmpString.toCharArray();
-	    for(int i=0;i<tmpArray.length;i++){
-		statStringArray[position] = tmpArray[i];
-		position++;
-	    }
-      
-	    position = 45;
-	    tmpString = new String(Double.toString(
-						   UtilFncs.adjustDoublePresision(this.getMeanNumberOfCalls(),
-										  precision)));
-	    tmpArray = tmpString.toCharArray();                       
-	    for(int i=0;i<tmpArray.length;i++){
-		statStringArray[position] = tmpArray[i];
-		position++;
-	    }
-      
-	    position = 63;
-	    tmpString = new String(Double.toString(
-						   UtilFncs.adjustDoublePresision(this.getMeanNumberOfSubRoutines(),
-										  precision)));
-	    tmpArray = tmpString.toCharArray();
-	    for(int i=0;i<tmpArray.length;i++){
-		statStringArray[position] = tmpArray[i];
-		position++;
-	    }
-      
-	    position = 81;
-	    tmpString = UtilFncs.getOutputString(type,this.getMeanUserSecPerCall(location),precision);
-
-	    tmpArray = tmpString.toCharArray();
-	    for(int i=0;i<tmpArray.length;i++){
-		statStringArray[position] = tmpArray[i];
-		position++;
-	    }
-      
-	    //Everything should be added now except the function name.
-	    return new String(statStringArray);
+	    return tmpString;
 	}
 	catch(Exception e){
+	    e.printStackTrace();
 	    UtilFncs.systemError(e, null, "GTDE01");
 	}
-    	return "An error occured pocessing this string!";
+    	return "An error occurred processing this string!";
     }
 
     public void setMeanValuesSet(boolean meanValuesSet){
@@ -482,19 +442,19 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
     public double getTotalExclusivePercentValue(int location){
 	return this.getDouble(location,13);}
 
-    public void setTotalNumberOfCalls(int i){
+    public void setTotalNumberOfCalls(double i){
 	totalNumberOfCalls = i;}
 
-    public void incrementTotalNumberOfCalls(int i){
+    public void incrementTotalNumberOfCalls(double i){
 	totalNumberOfCalls+=i;}
   
     public double getTotalNumberOfCalls(){
 	return totalNumberOfCalls;}
   
-    public void setTotalNumberOfSubRoutines(int i){
+    public void setTotalNumberOfSubRoutines(double i){
 	totalNumberOfSubRoutines = i;}
 
-    public void incrementTotalNumberOfSubRoutines(int i){
+    public void incrementTotalNumberOfSubRoutines(double i){
 	totalNumberOfSubRoutines+=i;}
   
     public double getTotalNumberOfSubRoutines(){
@@ -529,7 +489,7 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
 	return yBeg;}
   
     public int getYEnd(){
-    return yEnd;}
+	return yEnd;}
     //######
     //End - Draw section.
     //######
@@ -556,15 +516,18 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
     //######
     private void insertDouble(int location, int offset, double d){
 	try{
-	    doubleList[(location*14)+offset] = d;}
+	    doubleList[(location*15)+offset] = d;}
 	catch(Exception e){
 	    UtilFncs.systemError(e, null, "GME01");}
     }
   
     private double getDouble(int location, int offset){
 	try{
-	    return doubleList[(location*14)+offset];}
+	    return doubleList[(location*15)+offset];}
 	catch(Exception e){
+	    System.out.println("location: " + location);
+	    System.out.println("offset: " + offset);
+	    System.out.println("doubleList.length: " + doubleList.length);
 	    UtilFncs.systemError(e, null, "GME02");}
 	return -1;
     }
@@ -606,10 +569,11 @@ public class GlobalMappingElement implements Mapping, Serializable, Comparable{
     private double maxUserEventMinValue = 0;
     private double maxUserEventMaxValue = 0;
     private double maxUserEventMeanValue = 0;
+    private double maxUserEventSumSquared = 0;
     private double meanNumberOfCalls = 0;
     private double meanNumberOfSubRoutines = 0;
-    private int totalNumberOfCalls = 0;
-    private int totalNumberOfSubRoutines = 0;
+    private double totalNumberOfCalls = 0;
+    private double totalNumberOfSubRoutines = 0;
   
     //Drawing coordinates for this Global mapping element.
     private int xBeg;
