@@ -26,7 +26,6 @@ import java.util.*;
 
 public class TauOutputSession extends ParaProfDataSession{
 
-
     //####################################
     //Public Section.
     //####################################
@@ -42,7 +41,7 @@ public class TauOutputSession extends ParaProfDataSession{
     //End - Contructors.
     //######
 
-    public void run(){
+    public void initialize(Object initializeObject){
 	try{
 	    //Record time.
 	    long time = System.currentTimeMillis();
@@ -86,10 +85,13 @@ public class TauOutputSession extends ParaProfDataSession{
 	    //End - Frequently used items.
 	    //######
 	    v = (Vector) initializeObject;
+
+	    boolean validFilesFound = false;
+
 	    for(Enumeration e = v.elements(); e.hasMoreElements() ;){
 		System.out.println("Processing data, please wait ......");
 		if(this.debug())
-		    this.outputToFile("Processing data, please wait ......");
+		    this.outputDebugMessage("Processing data, please wait ......");
 		//Need to call increaseVectorStorage() on all objects that require it.
 		this.getGlobalMapping().increaseVectorStorage();
 
@@ -99,7 +101,7 @@ public class TauOutputSession extends ParaProfDataSession{
 		//Only need to call addDefaultToVectors() if not the first run.
 		if(!(metric==0)){
 		    if(this.debug())
-			this.outputToFile("Increasing the storage for the new metric.");
+			this.outputDebugMessage("Increasing the storage for the new metric.");
 		    
 		    for(Enumeration e1 = (this.getGlobalMapping().getMapping(0)).elements(); e1.hasMoreElements() ;){
 			GlobalMappingElement tmpGME = (GlobalMappingElement) e1.nextElement();
@@ -134,34 +136,27 @@ public class TauOutputSession extends ParaProfDataSession{
 		}
 
 		files = (File[]) e.nextElement();
-		for(int i=0;i<files.length;i++){
+		for(int i=0;i<files.length;i++) {
 		    if(this.debug()){
 			System.out.println("######");
 			System.out.println("Processing file: " + files[i].getName());
 			System.out.println("######");
-			this.outputToFile("######");
-			this.outputToFile("Processing file: " + files[i].getName());
-			this.outputToFile("######");
+			this.outputDebugMessage("Processing file: " + files[i].getName());
 		    }
 
-		    FileInputStream fileIn = new FileInputStream(files[i]);
-		    InputStreamReader inReader = new InputStreamReader(fileIn);
-		    BufferedReader br = new BufferedReader(inReader);
 
 		    int[] nct = this.getNCT(files[i].getName());
-		    nodeID = nct[0];
-		    contextID = nct[1];
-		    threadID = nct[2];
+		    if (nct!=null) {
+
+			FileInputStream fileIn = new FileInputStream(files[i]);
+			InputStreamReader inReader = new InputStreamReader(fileIn);
+			BufferedReader br = new BufferedReader(inReader);
+
+
+			nodeID = nct[0];
+			contextID = nct[1];
+			threadID = nct[2];
 
-		    if(nodeID<0||contextID<0||threadID<0){
-			System.out.println("Invalid n,c,t id: " + nct[0] + "," + nct[1] + "," + nct[2] +" ... not processing this file:");
-			System.out.println(files[i].getCanonicalPath());
-			if(this.debug()){
-			    this.outputToFile("Invalid n,c,t id: " + nct[0] + "," + nct[1] + "," + nct[2] +" ... not processing this file:");
-			    this.outputToFile(files[i].getCanonicalPath());
-			}
-		    }
-		    else{
 			node = this.getNCT().getNode(nodeID);
 			if(node==null)
 			    node = this.getNCT().addNode(nodeID);
@@ -174,7 +169,7 @@ public class TauOutputSession extends ParaProfDataSession{
 			    thread.setDebug(this.debug());
 			}
 			if(this.debug())
-			    this.outputToFile("n,c,t: " + nct[0] + "," + nct[1] + "," + nct[2]);
+			    this.outputDebugMessage("n,c,t: " + nct[0] + "," + nct[1] + "," + nct[2]);
 			
 			//####################################
 			//First  Line
@@ -183,10 +178,8 @@ public class TauOutputSession extends ParaProfDataSession{
 			if(inputString == null){
 			    System.out.println("Error processing file: " + files[i].getName());
 			    System.out.println("Unexpected end of file!");
-			    if(this.debug()){
-				this.outputToFile("Error processing file: " + files[i].getName());
-				this.outputToFile("Unexpected end of file!");
-			    }
+			    if(this.debug())
+				this.outputDebugMessage("Error processing file: "+files[i].getName()+"\nUnexpected end of file!");
 			    return;
 			}
 			genericTokenizer = new StringTokenizer(inputString, " \t\n\r");
@@ -200,10 +193,8 @@ public class TauOutputSession extends ParaProfDataSession{
 				metricName = new String("Time");
 			    this.addMetric(metricName);
 			    metricNameProcessed = true;
-			    if(this.debug()){
-				System.out.println("metric name: "+metricName);
-				this.outputToFile("metric name: "+metricName);
-			    }
+			    if(this.debug())
+				this.outputDebugMessage("metric name: "+metricName);
 			}
 			//####################################
 			//End - First Line
@@ -216,10 +207,8 @@ public class TauOutputSession extends ParaProfDataSession{
 			if(inputString == null){
 			    System.out.println("Error processing file: " + files[i].getName());
 			    System.out.println("Unexpected end of file!");
-			    if(this.debug()){
-				this.outputToFile("Error processing file: " + files[i].getName());
-				this.outputToFile("Unexpected end of file!");
-			    }
+			    if(this.debug())
+				this.outputDebugMessage("Error processing file: "+files[i].getName()+"\nUnexpected end of file!");
 			    return;
 			}
 			if(i==0){
@@ -232,10 +221,8 @@ public class TauOutputSession extends ParaProfDataSession{
 			//####################################
 
 			//Process the appropriate number of function lines.
-			if(this.debug()){
-			    this.outputToFile("######");
-			    this.outputToFile("processing functions");
-			}
+			if(this.debug())
+			    this.outputDebugMessage("processing functions");
 			numberOfLines = Integer.parseInt(tokenString);
 			for(int j=0;j<numberOfLines;j++){
 			    //On the off chance that we start supporting profiles with no functions in them
@@ -248,27 +235,17 @@ public class TauOutputSession extends ParaProfDataSession{
 			    if(inputString==null){
 				System.out.println("Error processing file: " + files[i].getName());
 				System.out.println("Unexpected end of file!");
-				if(this.debug()){
-				    this.outputToFile("Error processing file: " + files[i].getName());
-				    this.outputToFile("Unexpected end of file!");
-				}
+				if(this.debug())
+				    this.outputDebugMessage("Error processing file: "+files[i].getName()+"\nUnexpected end of file!");
 				return;
 			    }
+
 			    this.getFunctionDataLine(inputString);
 			    String groupNames = this.getGroupNames(inputString);
 			    //Calculate usec/call
-			    double usecCall = functionDataLine.d0/functionDataLine.i0;
-			    if(this.debug()){
-				this.outputToFile("function line: " + inputString);
-				this.outputToFile("Name:"+functionDataLine.s0);
-				this.outputToFile("Calls:"+functionDataLine.i0+
-						  " Subrs:"+functionDataLine.i1+
-						  " Excl:"+functionDataLine.d0+
-						  " Incl:"+functionDataLine.d1+
-						  " SumExclSqr:"+functionDataLine.d2+
-						  " ProfileCalls:"+functionDataLine.i2);
-				this.outputToFile("groupNames:"+groupNames);
-			    }
+			    double usecCall = functionDataLine.d1/functionDataLine.i0;
+			    if(this.debug())
+				this.outputDebugMessage("function line: "+inputString+"\nName:"+functionDataLine.s0+"Calls:"+functionDataLine.i0+" Subrs:"+functionDataLine.i1+" Excl:"+functionDataLine.d0+" Incl:"+functionDataLine.d1+" SumExclSqr:"+functionDataLine.d2+" ProfileCalls:"+functionDataLine.i2+"\ngroupNames:"+groupNames);
 			    if(functionDataLine.i0 !=0){
 				mappingID = this.getGlobalMapping().addGlobalMapping(functionDataLine.s0, 0, 1);
 				globalMappingElement = this.getGlobalMapping().getGlobalMappingElement(mappingID, 0);
@@ -279,11 +256,16 @@ public class TauOutputSession extends ParaProfDataSession{
 				    thread.addFunction(globalThreadDataElement, mappingID);
 				}
 			    
-				globalThreadDataElement.setExclusiveValue(metric, functionDataLine.d0);
-				globalThreadDataElement.setInclusiveValue(metric, functionDataLine.d1);
-				globalThreadDataElement.setNumberOfCalls(functionDataLine.i0);
-				globalThreadDataElement.setNumberOfSubRoutines(functionDataLine.i1);
-				globalThreadDataElement.setUserSecPerCall(metric, usecCall);
+				//When we encounter duplicate names in the profile.x.x.x file, treat as additional
+				//data for the name (that is, don't just overwrite what was there before).
+				//See todo item 7 in the ParaProf docs. directory.
+				globalThreadDataElement.setExclusiveValue(metric, globalThreadDataElement.getExclusiveValue(metric)+functionDataLine.d0);
+				globalThreadDataElement.setInclusiveValue(metric, globalThreadDataElement.getInclusiveValue(metric)+functionDataLine.d1);
+				if(metric==0){
+				    globalThreadDataElement.setNumberOfCalls(globalThreadDataElement.getNumberOfCalls()+functionDataLine.i0);
+				    globalThreadDataElement.setNumberOfSubRoutines(globalThreadDataElement.getNumberOfSubRoutines()+functionDataLine.i1);
+				}
+				globalThreadDataElement.setUserSecPerCall(metric, globalThreadDataElement.getUserSecPerCall(metric)+usecCall);
 			    
 				//Set the max values (thread max values are calculated in the edu.uoregon.tau.dms.dss.Thread class).
 				if((globalMappingElement.getMaxExclusiveValue(metric)) < functionDataLine.d0)
@@ -307,11 +289,8 @@ public class TauOutputSession extends ParaProfDataSession{
 						    //The potential new group is added here.  If the group is already present, the the addGlobalMapping
 						    //function will just return the already existing group id.  See the GlobalMapping class for more details.
 						    int groupID = this.getGlobalMapping().addGlobalMapping(group, 1, 1);
-						    if((groupID != -1) && (this.debug())){
-							this.outputToFile("######");
-							this.outputToFile("Adding " + group + " group with id: " + groupID + " to mapping: " + functionDataLine.s0);
-							this.outputToFile("######");
-						    }
+						    if((groupID != -1) && (this.debug()))
+							this.outputDebugMessage("Adding " + group + " group with id: " + groupID + " to mapping: " + functionDataLine.s0);
 						    globalMappingElement.addGroup(groupID);
 						}    
 					    }    
@@ -321,41 +300,35 @@ public class TauOutputSession extends ParaProfDataSession{
 
 			    }
 			
-			    if(this.debug()){
-				this.outputToFile("######");
-				this.outputToFile("processing profile calls for function: " + functionDataLine.s0);
-			    }
+			    if(this.debug())
+				this.outputDebugMessage("processing profile calls for function: " + functionDataLine.s0);
 			    //Process the appropriate number of profile call lines.
 			    for(int k=0;k<functionDataLine.i2;k++){
 				this.setProfileCallsPresent(true);
 				inputString = br.readLine();
 				if(this.debug())
-				    this.outputToFile("Profile Calls line: " + inputString);
+				    this.outputDebugMessage("Profile Calls line: " + inputString);
 				genericTokenizer = new StringTokenizer(inputString, " \t\n\r");
 				//Arguments are evaluated left to right.
 				globalThreadDataElement.addCall(Double.parseDouble(genericTokenizer.nextToken()),
 								Double.parseDouble(genericTokenizer.nextToken()));
 			    }
-			    if(this.debug()){
-				this.outputToFile("done processing profile calls for function: " + functionDataLine.s0);
-				this.outputToFile("######");
-			    }
-			}
-			if(this.debug()){
-			    this.outputToFile("done processing functions");
-			    this.outputToFile("######");
+			    if(this.debug())
+				this.outputDebugMessage("done processing profile calls for function: " + functionDataLine.s0);
 			}
+			if(this.debug())
+			    this.outputDebugMessage("done processing functions");
 		    
-			if(this.debug()){
-			    this.outputToFile("######");
-			    this.outputToFile("processing aggregates");
-			}
+			if(this.debug())
+			    this.outputDebugMessage("processing aggregates");
 			//Process the appropriate number of aggregate lines.
 			inputString = br.readLine();
 			//A valid profile.*.*.* will always contain this line.
 			if(inputString==null){
 			    System.out.println("Error processing file: " + files[i].getName());
 			    System.out.println("Unexpected end of file!");
+			    if(this.debug())
+				this.outputDebugMessage("Error processing file: "+files[i].getName()+"\nUnexpected end of file!");
 			    return;
 			}
 			genericTokenizer = new StringTokenizer(inputString, " \t\n\r");
@@ -367,25 +340,20 @@ public class TauOutputSession extends ParaProfDataSession{
 			    this.setAggregatesPresent(true);
 			    inputString = br.readLine();
 			    if(this.debug())
-				this.outputToFile("Aggregates line: " + inputString);
-			}
-			if(this.debug()){
-			    this.outputToFile("done processing aggregates");
-			    this.outputToFile("######");
+				this.outputDebugMessage("Aggregates line: " + inputString);
 			}
+			if(this.debug())
+			    this.outputDebugMessage("done processing aggregates");
 
 			if(metric==0){
 			    //Process the appropriate number of userevent lines.
-			    if(this.debug()){
-				this.outputToFile("######");
-				this.outputToFile("processing userevents");
-			    }
+			    if(this.debug())
+				this.outputDebugMessage("processing userevents");
 			    inputString = br.readLine();
-			    if(inputString==null){
+			    if (inputString==null) {
 				if(this.debug())
-				    this.outputToFile("No userevent data in this file.");
-			    }
-			    else{
+				    this.outputDebugMessage("No userevent data in this file.");
+			    } else {
 				genericTokenizer = new StringTokenizer(inputString, " \t\n\r");
 				//It's first token will be the number of userevents
 				tokenString = genericTokenizer.nextToken();
@@ -402,23 +370,16 @@ public class TauOutputSession extends ParaProfDataSession{
 				    if(inputString==null){
 					System.out.println("Error processing file: " + files[i].getName());
 					System.out.println("Unexpected end of file!");
-					if(this.debug()){
-					    this.outputToFile("Error processing file: " + files[i].getName());
-					    this.outputToFile("Unexpected end of file!");
-					}
+					if(this.debug())
+					    this.outputDebugMessage("Error processing file: "+files[i].getName()+"\nUnexpected end of file!");
 					return;
 				    }
 				    this.getUserEventData(inputString);
-				    if(this.debug()){
-					this.outputToFile("userevent line: " + inputString);
-					this.outputToFile("eventname:"+usereventDataLine.s0);
-					this.outputToFile("numevents:"+usereventDataLine.i0+
-							  " max:"+usereventDataLine.d0+
-							  " min:"+usereventDataLine.d1+
-							  " mean:"+usereventDataLine.d2+
-							  " sumsqr:"+usereventDataLine.d3);
-				    }
-				    if(usereventDataLine.i0 !=0){
+				    if(this.debug())
+					this.outputDebugMessage("userevent line: "+inputString+"\neventname:"+usereventDataLine.s0+"\nnumevents:"+usereventDataLine.i0+" max:"+usereventDataLine.d0+" min:"+usereventDataLine.d1+" mean:"+usereventDataLine.d2+" sumsqr:"+usereventDataLine.d3);
+				   
+				    // User events
+				    if (usereventDataLine.i0 !=0) {
 					mappingID = this.getGlobalMapping().addGlobalMapping(usereventDataLine.s0, 2, 1);
 					globalMappingElement = this.getGlobalMapping().getGlobalMappingElement(mappingID, 2);
 					globalThreadDataElement = thread.getUserevent(mappingID);
@@ -432,7 +393,8 @@ public class TauOutputSession extends ParaProfDataSession{
 					globalThreadDataElement.setUserEventMaxValue(usereventDataLine.d0);
 					globalThreadDataElement.setUserEventMinValue(usereventDataLine.d1);
 					globalThreadDataElement.setUserEventMeanValue(usereventDataLine.d2);
-				    
+					globalThreadDataElement.setUserEventSumSquared(usereventDataLine.d3);
+    
 					if((globalMappingElement.getMaxUserEventNumberValue()) < usereventDataLine.i0)
 					    globalMappingElement.setMaxUserEventNumberValue(usereventDataLine.i0);
 					if((globalMappingElement.getMaxUserEventMaxValue()) < usereventDataLine.d0)
@@ -441,25 +403,40 @@ public class TauOutputSession extends ParaProfDataSession{
 					    globalMappingElement.setMaxUserEventMinValue(usereventDataLine.d1);
 					if((globalMappingElement.getMaxUserEventMeanValue()) < usereventDataLine.d2)
 					    globalMappingElement.setMaxUserEventMeanValue(usereventDataLine.d2);
+					if((globalMappingElement.getMaxUserEventSumSquared()) < usereventDataLine.d3)
+					    globalMappingElement.setMaxUserEventSumSquared(usereventDataLine.d3);
 				    }
 				}
 			    }
-			    if(this.debug()){
-				this.outputToFile("done processing userevents");
-				this.outputToFile("######");
-			    }
+			    if(this.debug())
+				this.outputDebugMessage("done processing userevents");
 			}
-			thread.setThreadData(metric);
+			//Remove after testing is complete.
+			//thread.setThreadData(metric);
+
+			validFilesFound = true;
+
+			br.close();
+			inReader.close();
+			fileIn.close();
 		    }
+
 		}
 		metric++;
 	    }
-	    //Generate mean data.
-	    this.setMeanDataAllMetrics(0,this.getNumberOfMetrics());
+
+	    if (!validFilesFound)
+		throw new Exception("No valid profiles found");
+
+
+	    //Generate derived data.
+	    this.generateDerivedData(0);
+	    //Remove after testing is complete.
+	    //this.setMeanDataAllMetrics(0);
 
 	    System.out.println("Processing callpath data ...");
 	    if(this.debug())
-		this.outputToFile("Processing callpath data ...");
+		this.outputDebugMessage("Processing callpath data ...");
 	    if(CallPathUtilFuncs.isAvailable(getGlobalMapping().getMappingIterator(0))){
 		setCallPathDataPresent(true);
 		CallPathUtilFuncs.buildRelations(getGlobalMapping());
@@ -467,45 +444,41 @@ public class TauOutputSession extends ParaProfDataSession{
 	    else{
 		System.out.println("No callpath data found.");
 		if(this.debug())
-		    this.outputToFile("No callpath data found.");
+		    this.outputDebugMessage("No callpath data found.");
 	    }
 	    System.out.println("Done - Processing callpath data!");
 	    if(this.debug())
-		this.outputToFile("Done - Processing callpath data!");
+		this.outputDebugMessage("Done - Processing callpath data!");
 
 	    time = (System.currentTimeMillis()) - time;
 	    System.out.println("Done processing data!");
 	    System.out.println("Time to process (in milliseconds): " + time);
-	    if(this.debug()){
-		this.outputToFile("Done processing data!");
-		this.outputToFile("Time to process (in milliseconds): " + time);
-	    }
-
+	    if(this.debug())
+		this.outputDebugMessage("Done processing data!"+"\nTime to process (in milliseconds): "+time);
 	    this.flushDebugFileBuffer();
 	    this.closeDebugFile();
-
-	    //Need to notify observers that we are done.  Be careful here.
-	    //It is likely that they will modify swing elements.  Make sure
-	    //to dump request onto the event dispatch thread to ensure
-	    //safe update of said swing elements.  Remember, swing is not thread
-	    //safe for the most part.
-	    EventQueue.invokeLater(new Runnable(){
-		    public void run(){
-			TauOutputSession.this.notifyObservers();
-		    }
-		});
 	}
         catch(Exception e){
-	    UtilFncs.systemError(e, null, "SSD01");
+	    UtilFncs.systemError(new ParaProfError(this.toString()+": run()", null,
+						   "An error occurred while trying to load!\nExpected format to be of type \"profiles\".",
+						   "Please check for the correct file type or a corrupt file.",
+						   e, null, null, null, false,false, false),null,null);
+	    if(this.debug())
+		this.outputDebugMessage("run()\nAn error occurred whilst trying to load!\nExpected format to be of type \"profiles\".");
 	}
     }
 
+    public void outputDebugMessage(String debugMessage){
+	UtilFncs.objectDebug.outputToFile(this.toString()+"\n"+debugMessage);}
+
+    public String toString(){
+	return this.getClass().getName();}
+
     public static void main(String[] args){
     }
     //####################################
     //End - Public Section.
     //####################################
-
     
     //####################################
     //Private Section.
@@ -515,13 +488,32 @@ public class TauOutputSession extends ParaProfDataSession{
     //profile.*.*.* string processing methods.
     //######
     private int[] getNCT(String string){
-	int[] nct = new int[3];
-	StringTokenizer st = new StringTokenizer(string, ".\t\n\r");
-	st.nextToken();
-	nct[0] = Integer.parseInt(st.nextToken());
-	nct[1] = Integer.parseInt(st.nextToken());
-	nct[2] = Integer.parseInt(st.nextToken());
-	return nct;
+	try{
+	    int[] nct = new int[3];
+	    StringTokenizer st = new StringTokenizer(string, ".\t\n\r");
+	    st.nextToken();
+	    nct[0] = Integer.parseInt(st.nextToken());
+	    nct[1] = Integer.parseInt(st.nextToken());
+	    nct[2] = Integer.parseInt(st.nextToken());
+
+	    if(nct[0]<0||nct[1]<0||nct[2]<0){
+		UtilFncs.systemError(new ParaProfError(this.toString()+": getNCT(...)",
+						       "An error occurred whilst processing file: " + string,
+						       "This file will be ignored!"),null,null);
+		if(this.debug())
+		    this.outputDebugMessage("getNCT(...)\nAn error occurred whilst processing file: " + string + "\nThis file will be ignored!");
+		return null;
+	    }
+	    return nct;
+	}
+	catch(Exception e){
+	    UtilFncs.systemError(new ParaProfError(this.toString()+": getNCT(...)",
+						   "An error occurred whilst processing file: " + string,
+						   "This file will be ignored!"),null,null);
+	    if(this.debug())
+		this.outputDebugMessage("getNCT(...)\nAn error occurred whilst processing file: " + string + "\nThis file will be ignored!");
+	    return null;
+	}
     }
   
     private String getMetricName(String inString){
@@ -535,7 +527,16 @@ public class TauOutputSession extends ParaProfDataSession{
 		tmpString = inString.substring(tmpInt+7);
 		return tmpString;
 	    }
-      	    //We are not reading data from a multiple counter run.
+
+
+	    tmpInt = inString.indexOf("hw_counters");
+	    if(tmpInt > 0){
+		//We are reading data from a hardware counter run.
+		return "Hardware Counter";
+	    }
+	   
+
+      	    //We are not reading data from a multiple counter run or hardware counter run.
 	    return tmpString; 
       	}
 	catch(Exception e){
@@ -546,30 +547,76 @@ public class TauOutputSession extends ParaProfDataSession{
     }
 
     private void getFunctionDataLine(String string){
-	try{
+
+	// first, count the number of double-quotes to determine if the 
+	// function contains a double-quote
+	int quoteCount = 0;
+ 	for (int i=0; i < string.length(); i++) {
+	    if (string.charAt(i) == '"')
+		quoteCount++;
+	}
+
+	StringTokenizer st2;
+
+	if (quoteCount == 2 || quoteCount == 4) { // assume all is well
 	    StringTokenizer st1 = new StringTokenizer(string, "\"");
 	    functionDataLine.s0 = st1.nextToken(); //Name
 	    
-	    StringTokenizer st2 = new StringTokenizer(st1.nextToken(), " \t\n\r");
-	    functionDataLine.i0 = Integer.parseInt(st2.nextToken()); //Calls
-	    functionDataLine.i1 = Integer.parseInt(st2.nextToken()); //Subroutines
-	    functionDataLine.d0 = Double.parseDouble(st2.nextToken()); //Exclusive
-	    functionDataLine.d1 = Double.parseDouble(st2.nextToken()); //Inclusive
-	    if(this.profileStatsPresent())
-		functionDataLine.d2 = Double.parseDouble(st2.nextToken()); //SumExclSqr
-	    functionDataLine.i2 = Integer.parseInt(st2.nextToken()); //ProfileCalls
-	}
-	catch(Exception e){
-	    UtilFncs.systemError(e, null, "SSD08");
+	    st2 = new StringTokenizer(st1.nextToken(), " \t\n\r");
+	} else {
+
+	    // there is a quote in the name of the timer/function
+	    // we assume that TAU_GROUP="..." is there, so the end of the name must be
+	    // at quoteCount - 2
+	    int count = 0;
+	    int i = 0;
+	    while (count < quoteCount - 2 && i < string.length()) {
+		if (string.charAt(i) == '"')
+		    count++;
+		i++;
+	    }
+	    
+	    functionDataLine.s0 = string.substring(1,i-1);
+	    st2 = new StringTokenizer(string.substring(i+1), " \t\n\r");
 	}
+	
+	functionDataLine.i0 = Integer.parseInt(st2.nextToken()); //Calls
+	functionDataLine.i1 = Integer.parseInt(st2.nextToken()); //Subroutines
+	functionDataLine.d0 = Double.parseDouble(st2.nextToken()); //Exclusive
+	functionDataLine.d1 = Double.parseDouble(st2.nextToken()); //Inclusive
+	if (this.profileStatsPresent())
+	    functionDataLine.d2 = Double.parseDouble(st2.nextToken()); //SumExclSqr
+	functionDataLine.i2 = Integer.parseInt(st2.nextToken()); //ProfileCalls
+	
     }
 
     private String getGroupNames(String string){
 	try{  
-	    StringTokenizer getMappingNameTokenizer = new StringTokenizer(string, "\"");
- 	    getMappingNameTokenizer.nextToken();
+
+
+	    // first, count the number of double-quotes to determine if the 
+	    // function contains a double-quote
+	    int quoteCount = 0;
+	    for (int i=0; i < string.length(); i++) {
+		if (string.charAt(i) == '"')
+		    quoteCount++;
+	    }
+	    
+	    
+	    // there is a quote in the name of the timer/function
+	    // we assume that TAU_GROUP="..." is there, so the end of the name must be
+	    // at quoteCount - 2
+	    int count = 0;
+	    int i = 0;
+	    while (count < quoteCount - 2 && i < string.length()) {
+		if (string.charAt(i) == '"')
+		    count++;
+		i++;
+	    }
+
+	    StringTokenizer getMappingNameTokenizer = new StringTokenizer(string.substring(i+1), "\"");
 	    String str = getMappingNameTokenizer.nextToken();
-        
+	    
 	    //Just do the group check once.
 	    if(!(this.groupCheck())){
 		//If present, "GROUP=" will be in this token.
@@ -581,8 +628,8 @@ public class TauOutputSession extends ParaProfDataSession{
 	    }
 	    
 	    if(groupNamesPresent()){
-		 str = getMappingNameTokenizer.nextToken();
-		    return str;
+		str = getMappingNameTokenizer.nextToken();
+		return str;
 	    }
 	    //If here, this profile file does not track the group names.
 	    return null;
@@ -595,10 +642,36 @@ public class TauOutputSession extends ParaProfDataSession{
 
     private void getUserEventData(String string){
 	try{
-	    StringTokenizer st1 = new StringTokenizer(string, "\"");
-	    usereventDataLine.s0 = st1.nextToken();
 
-	    StringTokenizer st2 = new StringTokenizer(st1.nextToken(), " \t\n\r");
+	    // first, count the number of double-quotes to determine if the 
+	    // user event contains a double-quote
+	    int quoteCount = 0;
+	    for (int i=0; i < string.length(); i++) {
+		if (string.charAt(i) == '"')
+		    quoteCount++;
+	    }
+
+	    StringTokenizer st2;
+
+	    if (quoteCount == 2) { // proceed as usual
+		StringTokenizer st1 = new StringTokenizer(string, "\"");
+		usereventDataLine.s0 = st1.nextToken();
+		st2 = new StringTokenizer(st1.nextToken(), " \t\n\r");
+	    } else {
+
+		// there is a quote in the name of the user event
+		int count = 0;
+		int i = 0;
+		while (count < quoteCount && i < string.length()) {
+		    if (string.charAt(i) == '"')
+			count++;
+		    i++;
+		}
+	    
+		usereventDataLine.s0 = string.substring(1,i-1);
+		st2 = new StringTokenizer(string.substring(i+1), " \t\n\r");
+	    }
+
 	    usereventDataLine.i0 = (int) Double.parseDouble(st2.nextToken()); //Number of calls.
 	    usereventDataLine.d0 = Double.parseDouble(st2.nextToken()); //Max
 	    usereventDataLine.d1 = Double.parseDouble(st2.nextToken()); //Min
@@ -606,7 +679,7 @@ public class TauOutputSession extends ParaProfDataSession{
 	    usereventDataLine.d3 = Double.parseDouble(st2.nextToken()); //Standard Deviation.
 	}
 	catch(Exception e){
-	    System.out.println("An error occured!");
+	    System.out.println("An error occurred!");
 	    e.printStackTrace();
 	}
     }
