@@ -23,12 +23,22 @@ import java.util.*;
 
 public class TauPprofOutputSession extends ParaProfDataSession{
 
+    //####################################
+    //Public Section.
+    //####################################
+
+    //######
+    //Contructors.
+    //######
     public TauPprofOutputSession(){
 	super();
 	this.setMetrics(new Vector());
     }
+    //######
+    //End - Contructors.
+    //######
 
-    public void run(){
+    public void initialize(Object initializeObject){
 	try{
 	    //######
 	    //Frequently used items.
@@ -135,7 +145,7 @@ public class TauPprofOutputSession extends ParaProfDataSession{
 		if(metricName == null)
 		    metricName = new String("Time");
 
-		System.out.println("Metric name is: " + metricName);
+		//		System.out.println("Metric name is: " + metricName);
       
 		metric = this.getNumberOfMetrics();
 		this.addMetric(metricName);
@@ -380,6 +390,7 @@ public class TauPprofOutputSession extends ParaProfDataSession{
 				    globalThreadDataElement.setUserEventMinValue(usereventDataLine.d1);
 				    globalThreadDataElement.setUserEventMaxValue(usereventDataLine.d0);
 				    globalThreadDataElement.setUserEventMeanValue(usereventDataLine.d2);
+				    globalThreadDataElement.setUserEventSumSquared(usereventDataLine.d3);
 
 				    if((globalMappingElement.getMaxUserEventNumberValue()) < usereventDataLine.i0)
 					globalMappingElement.setMaxUserEventNumberValue(usereventDataLine.i0);
@@ -389,6 +400,11 @@ public class TauPprofOutputSession extends ParaProfDataSession{
 					globalMappingElement.setMaxUserEventMinValue(usereventDataLine.d1);
 				    if((globalMappingElement.getMaxUserEventMeanValue()) < usereventDataLine.d2)
 					globalMappingElement.setMaxUserEventMeanValue(usereventDataLine.d2);
+
+
+				    if(globalMappingElement.getMaxUserEventSumSquared() < usereventDataLine.d3)
+					globalMappingElement.setMaxUserEventSumSquared(usereventDataLine.d3);
+
 				}
 			    }
 			    //Now set the userevents flag.
@@ -422,30 +438,38 @@ public class TauPprofOutputSession extends ParaProfDataSession{
 		System.out.println("Done processing data file!");
 		System.out.println("Time to process file (in milliseconds): " + time);
 	    }
-	    System.out.println("Processing callpath data ...");
+
+	    //System.out.println("Processing callpath data ...");
 	    if(CallPathUtilFuncs.isAvailable(getGlobalMapping().getMappingIterator(0))){
 		setCallPathDataPresent(true);
 		CallPathUtilFuncs.buildRelations(getGlobalMapping());
 	    }
-	    else
-		System.out.println("No callpath data found.");
-	    System.out.println("Done - Processing callpath data!");
-
-	    //Need to notify observers that we are done.  Be careful here.
-	    //It is likely that they will modify swing elements.  Make sure
-	    //to dump request onto the event dispatch thread to ensure
-	    //safe update of said swing elements.  Remember, swing is not thread
-	    //safe for the most part.
-	    EventQueue.invokeLater(new Runnable(){
-		    public void run(){
-			TauPprofOutputSession.this.notifyObservers();
-		    }
-		});
+	    else {
+		//System.out.println("No callpath data found.");
+	    }
+	    //System.out.println("Done - Processing callpath data!");
 	}
         catch(Exception e){
-	    UtilFncs.systemError(e, null, "SSD01");
+	    UtilFncs.systemError(new ParaProfError(this.toString()+": run()", null,
+						   "An error occurred whilst trying to load!\nExpected format to be of type \"pprof\".",
+						   "Please check for the correct file type or a corrupt file.",
+						   e, null, null, null, false,false, false),null,null);
+	    if(this.debug())
+		this.outputDebugMessage(this.toString()+": run()\nAn error occurred whilst trying to load!\nExpected format to be of type \"profiles\".");
 	}
     }
+
+    public void outputDebugMessage(String debugMessage){
+	UtilFncs.objectDebug.outputToFile(this.toString()+"\n"+debugMessage);}
+
+    public String toString(){
+	return this.getClass().getName();}
+
+    public static void main(String[] args){
+    }
+    //####################################
+    //End - Public Section.
+    //####################################
     
     //####################################
     //Private Section.
@@ -483,15 +507,42 @@ public class TauPprofOutputSession extends ParaProfDataSession{
 		    return result;
 	    }
       
-	    //Now, we want to grab the substring that occurs AFTER the SECOND '"'.
-	    //At present, pprof does not seem to allow an '"' in the mapping name.  So
-	    //, I can be assured that I will not find more than two before the "excl" or "incl".
-	    StringTokenizer checkQuotesTokenizer = new StringTokenizer(inString,"\"");
-      
-	    //Need to get the third token.  Could do it in a loop, just as quick this way.
-	    String tmpString = checkQuotesTokenizer.nextToken();
-	    tmpString = checkQuotesTokenizer.nextToken();
-	    tmpString = checkQuotesTokenizer.nextToken();
+
+
+	    // first, count the number of double-quotes to determine if the 
+	    // function contains a double-quote
+	    int quoteCount = 0;
+	    for (int i=0; i < inString.length(); i++) {
+		if (inString.charAt(i) == '"')
+		    quoteCount++;
+	    }
+	    
+	    StringTokenizer st2;
+
+	    String tmpString;
+	    if (quoteCount == 2 || quoteCount == 4) { // assume all is well
+		StringTokenizer checkQuotesTokenizer = new StringTokenizer(inString,"\"");
+		
+		//Need to get the third token.  Could do it in a loop, just as quick this way.
+		tmpString = checkQuotesTokenizer.nextToken();
+		tmpString = checkQuotesTokenizer.nextToken();
+		tmpString = checkQuotesTokenizer.nextToken();
+		
+	    } else {
+
+		// there is a quote in the name of the timer/function
+		// we assume that TAU_GROUP="..." is there, so the end of the name must be
+		// at quoteCount - 2
+		int count = 0;
+		int i = 0;
+		while (count < quoteCount - 2 && i < inString.length()) {
+		    if (inString.charAt(i) == '"')
+			count++;
+		    i++;
+		}
+		tmpString = inString.substring(i+1);
+	    }
+
       
 	    //Ok, now, the string in tmpString should include at least "excl" or "incl", and
 	    //also, the first token should be either "excl" or "incl".
@@ -515,11 +566,45 @@ public class TauPprofOutputSession extends ParaProfDataSession{
 
     private void getFunctionDataLine1(String string){
 	try{
-	    StringTokenizer st1 = new StringTokenizer(string, "\"");
-	    st1.nextToken();
-	    functionDataLine1.s0 = st1.nextToken(); //Name
+
+	    // first, count the number of double-quotes to determine if the 
+	    // function contains a double-quote
+	    int quoteCount = 0;
+	    for (int i=0; i < string.length(); i++) {
+		if (string.charAt(i) == '"')
+		    quoteCount++;
+	    }
 	    
-	    StringTokenizer st2 = new StringTokenizer(st1.nextToken(), " \t\n\r");
+	    StringTokenizer st2;
+
+	    if (quoteCount == 2 || quoteCount == 4) { // assume all is well
+		StringTokenizer st1 = new StringTokenizer(string, "\"");
+		st1.nextToken();
+		functionDataLine1.s0 = st1.nextToken(); //Name
+		
+		st2 = new StringTokenizer(st1.nextToken(), " \t\n\r");
+
+	    } else {
+		// there is a quote in the name of the timer/function
+		// we assume that TAU_GROUP="..." is there, so the end of the name must be
+		// at quoteCount - 2
+		int count = 0;
+		int i = 0;
+		
+		int firstQuote = -1;
+		while (count < quoteCount - 2 && i < string.length()) {
+		    if (string.charAt(i) == '"') {
+			if (firstQuote == -1)
+			    firstQuote = i;
+			count++;
+		    }
+		    i++;
+		}
+		
+		functionDataLine1.s0 = string.substring(firstQuote+1,i-1); // get the name
+		st2 = new StringTokenizer(string.substring(i+1), " \t\n\r");
+	    }
+
 	    st2.nextToken();
 	    functionDataLine1.d0 = Double.parseDouble(st2.nextToken()); //Value
 	    functionDataLine1.d1 = Double.parseDouble(st2.nextToken()); //Percent value
@@ -537,6 +622,7 @@ public class TauPprofOutputSession extends ParaProfDataSession{
 	    getMappingIDTokenizer.nextToken();
 	    
 	    functionDataLine2.i0 = (int) Double.parseDouble(getMappingIDTokenizer.nextToken()); //Number of calls
+
 	    functionDataLine2.i1 = (int) Double.parseDouble(getMappingIDTokenizer.nextToken()); //Number of subroutines
 	    functionDataLine2.d0 = Double.parseDouble(getMappingIDTokenizer.nextToken()); //User seconds per call
 	}
@@ -547,19 +633,65 @@ public class TauPprofOutputSession extends ParaProfDataSession{
 
     private void getUserEventData(String string){
 	try{
-	    StringTokenizer st1 = new StringTokenizer(string, "\"");
-	    st1.nextToken();
-	    usereventDataLine.s0 = st1.nextToken();
 
-	    StringTokenizer st2 = new StringTokenizer(st1.nextToken(), " \t\n\r");
+	    // first, count the number of double-quotes to determine if the 
+	    // user event contains a double-quote
+	    int quoteCount = 0;
+	    for (int i=0; i < string.length(); i++) {
+		if (string.charAt(i) == '"')
+		    quoteCount++;
+	    }
+
+	    StringTokenizer st2;
+
+	    if (quoteCount == 2) { // proceed as usual
+		StringTokenizer st1 = new StringTokenizer(string, "\"");
+		String trash = st1.nextToken();
+		usereventDataLine.s0 = st1.nextToken();
+		st2 = new StringTokenizer(st1.nextToken(), " \t\n\r");
+	    } else {
+
+		// there is a quote in the name of the user event
+		int count = 0;
+		int i = 0;
+
+
+		int firstQuote = -1;
+		while (count < quoteCount && i < string.length()) {
+		    if (string.charAt(i) == '"') {
+			if (firstQuote == -1)
+			    firstQuote = i;
+			count++;
+		    }
+		    i++;
+		}
+
+		usereventDataLine.s0 = string.substring(firstQuote+1,i-1);
+		st2 = new StringTokenizer(string.substring(i+1), " \t\n\r");
+	    }
+
 	    usereventDataLine.i0 = (int) Double.parseDouble(st2.nextToken()); //Number of calls.
 	    usereventDataLine.d0 = Double.parseDouble(st2.nextToken()); //Max
 	    usereventDataLine.d1 = Double.parseDouble(st2.nextToken()); //Min
 	    usereventDataLine.d2 = Double.parseDouble(st2.nextToken()); //Mean
 	    usereventDataLine.d3 = Double.parseDouble(st2.nextToken()); //Standard Deviation.
+
+
+	    // Sum Squared = [ (stddev)^2 + (mean)^2] * N
+
+	    usereventDataLine.d3 = ((usereventDataLine.d3 * usereventDataLine.d3) + (usereventDataLine.d2 * usereventDataLine.d2)) * usereventDataLine.i0;
+	    
+
+	    /*	    System.out.println ("numSamples = " + usereventDataLine.i0);
+	    System.out.println ("max = " + usereventDataLine.d0);
+	    System.out.println ("min = " + usereventDataLine.d1);
+	    System.out.println ("mean = " + usereventDataLine.d2);
+	    System.out.println ("sumsqr? = " + usereventDataLine.d3);
+	    */
+
 	}
 	catch(Exception e){
-	    System.out.println("An error occured!");
+	    System.out.println("An error occurred!");
 	    e.printStackTrace();
 	}
     }
